﻿using System.ComponentModel;

namespace prism.Model
{
    public class CPerson : INotifyPropertyChanged
    {
        #region Fields

        private string _lastName;
        private string _email;
        private string _firstName;
        private string _city;

        #endregion

        #region Properties

        public string LastName
        {
            get { return _lastName; }
            set
            {
                if (_lastName != value)
                {
                    _lastName = value;
                    NotifyPropertyChanged("LastName");
                }
            }
        }

        public string Email
        {
            get { return _email; }
            set
            {
                if (_email != value)
                {
                    _email = value;
                    NotifyPropertyChanged("Email");
                }
            }
        }

        public string FirstName
        {
            get { return _firstName; }
            set
            {
                if (_firstName != value)
                {
                    _firstName = value;
                    NotifyPropertyChanged("FirstName");
                }
            }
        }

        public string City
        {
            get { return _city; }
            set
            {
                if (_city != value)
                {
                    _city = value;
                    NotifyPropertyChanged("City");
                }
            }
        }

        #endregion

        #region Constructor/Destructors

        public CPerson()
        {
        }

        public CPerson(CPerson person)
        {
            if (person != null)
            {
                FirstName = person.FirstName;
                City = person.City;
                Email = person.Email;
                LastName = person.LastName;
            }
        }

        #endregion

        #region Methods

        public void Copy(CPerson person)
        {
            FirstName = person.FirstName;
            City = person.City;
            Email = person.Email;
            LastName = person.LastName;
        }

        private void NotifyPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        #endregion

        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;

        #endregion
    }
}