﻿using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Windows.Input;
using Microsoft.Practices.Prism.Commands;
using prism.Model;

namespace prism.Viewmodel
{
    public class MainViewModel : INotifyPropertyChanged
    {
        #region Fields

        private readonly ObservableCollection<CPerson> _personList =
            new ObservableCollection<CPerson>();

        private ICommand _commandPersonDelete;
        private ICommand _commandPersonDiscard;
        private ICommand _commandPersonNew;
        private ICommand _commandPersonSave;
        private CPerson _detailViewPerson;
        private CPerson _selectedPerson;

        #endregion

        #region Properties

        public ICommand CommandPersonDelete
        {
            get
            {
                if (_commandPersonDelete == null)
                {
                    _commandPersonDelete = new DelegateCommand(() =>
                                                                   {
                                                                       _personList.Remove(SelectedPerson);
                                                                       if (_personList.Count > 0)
                                                                       {
                                                                           SelectedPerson = _personList[0];
                                                                       }
                                                                   });
                }

                return _commandPersonDelete;
            }
        }

        public ICommand CommandPersonDiscard
        {
            get
            {
                if (_commandPersonDiscard == null)
                {
                    _commandPersonDiscard = new DelegateCommand(() => DetailViewPerson = new CPerson(_selectedPerson));
                }

                return _commandPersonDiscard;
            }
        }

        public ICommand CommandPersonNew
        {
            get
            {
                if (_commandPersonNew == null)
                {
                    _commandPersonNew = new DelegateCommand(() =>
                                                                {
                                                                    var person = new CPerson();
                                                                    _personList.Add(person);
                                                                    SelectedPerson = person;
                                                                });
                }

                return _commandPersonNew;
            }
        }

        public ICommand CommandPersonSave
        {
            get
            {
                if (_commandPersonSave == null)
                {
                    _commandPersonSave = new DelegateCommand(() =>
                                                                 {
                                                                     if (_personList.Count == 0)
                                                                     {
                                                                         var person = new CPerson(_detailViewPerson);
                                                                         _personList.Add(person);
                                                                         SelectedPerson = person;
                                                                     }
                                                                     else
                                                                     {
                                                                         SelectedPerson.Copy(_detailViewPerson);
                                                                         CPerson person = SelectedPerson;
                                                                         SelectedPerson = person;
                                                                     }
                                                                 });
                }

                return _commandPersonSave;
            }
        }

        public CPerson DetailViewPerson
        {
            get { return _detailViewPerson; }
            set
            {
                _detailViewPerson = value;
                NotifyPropertyChanged("DetailViewPerson");
            }
        }

        public ObservableCollection<CPerson> PersonList
        {
            get { return _personList; }
        }

        public CPerson SelectedPerson
        {
            get { return _selectedPerson; }
            set
            {
                _selectedPerson = value;
                DetailViewPerson = new CPerson(_selectedPerson);
                NotifyPropertyChanged("SelectedPerson");
            }
        }

        #endregion

        #region Constructor/Destructors

        public MainViewModel()
        {
            _personList.Add(new CPerson
                                {LastName = "Miller", Email = "bill@gmail.com", FirstName = "Bill", City = "Las Vegas"});
            _personList.Add(new CPerson
                                {LastName = "Contonso", Email = "sam@hotmail.com", FirstName = "Sam", City = "Zurich"});
            SelectedPerson = _personList[0];
        }

        #endregion

        #region Methods

        private void NotifyPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        #endregion

        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;

        #endregion
    }
}